==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/github/AutoApproveOptions.java <==
package io.github.cdklabs.projen.github;

/**
 * (experimental) Options for 'AutoApprove'.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.738Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.github.AutoApproveOptions")
@software.amazon.jsii.Jsii.Proxy(AutoApproveOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface AutoApproveOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) A GitHub secret name which contains a GitHub Access Token with write permissions for the `pull_request` scope.
     * <p>
     * This token is used to approve pull requests.
     * <p>
     * Github forbids an identity to approve its own pull request.
     * If your project produces automated pull requests using the Github default token -
     * {&#64;link https://docs.github.com/en/actions/reference/authentication-in-a-workflow <code>GITHUB_TOKEN</code> }
     * <p>
     * <ul>
     * <li>that you would like auto approved, such as when using the <code>depsUpgrade</code> property in
     * <code>NodeProjectOptions</code>, then you must use a different token here.</li>
     * </ul>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull java.lang.String getSecret();

    /**
     * (experimental) Only pull requests authored by these Github usernames will be auto-approved.
     * <p>
     * Default: ['github-bot']
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getAllowedUsernames() {
        return null;
    }

    /**
     * (experimental) Only pull requests with this label will be auto-approved.
     * <p>
     * Default: 'auto-approve'
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getLabel() {
        return null;
    }

    /**
     * (experimental) Github Runner selection labels.
     * <p>
     * Default: ["ubuntu-latest"]
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getRunsOn() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link AutoApproveOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link AutoApproveOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<AutoApproveOptions> {
        java.lang.String secret;
        java.util.List<java.lang.String> allowedUsernames;
        java.lang.String label;
        java.util.List<java.lang.String> runsOn;

        /**
         * Sets the value of {@link AutoApproveOptions#getSecret}
         * @param secret A GitHub secret name which contains a GitHub Access Token with write permissions for the `pull_request` scope. This parameter is required.
         *               This token is used to approve pull requests.
         *               <p>
         *               Github forbids an identity to approve its own pull request.
         *               If your project produces automated pull requests using the Github default token -
         *               {&#64;link https://docs.github.com/en/actions/reference/authentication-in-a-workflow <code>GITHUB_TOKEN</code> }
         *               <p>
         *               <ul>
         *               <li>that you would like auto approved, such as when using the <code>depsUpgrade</code> property in
         *               <code>NodeProjectOptions</code>, then you must use a different token here.</li>
         *               </ul>
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder secret(java.lang.String secret) {
            this.secret = secret;
            return this;
        }

        /**
         * Sets the value of {@link AutoApproveOptions#getAllowedUsernames}
         * @param allowedUsernames Only pull requests authored by these Github usernames will be auto-approved.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder allowedUsernames(java.util.List<java.lang.String> allowedUsernames) {
            this.allowedUsernames = allowedUsernames;
            return this;
        }

        /**
         * Sets the value of {@link AutoApproveOptions#getLabel}
         * @param label Only pull requests with this label will be auto-approved.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder label(java.lang.String label) {
            this.label = label;
            return this;
        }

        /**
         * Sets the value of {@link AutoApproveOptions#getRunsOn}
         * @param runsOn Github Runner selection labels.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder runsOn(java.util.List<java.lang.String> runsOn) {
            this.runsOn = runsOn;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link AutoApproveOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public AutoApproveOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link AutoApproveOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements AutoApproveOptions {
        private final java.lang.String secret;
        private final java.util.List<java.lang.String> allowedUsernames;
        private final java.lang.String label;
        private final java.util.List<java.lang.String> runsOn;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.secret = software.amazon.jsii.Kernel.get(this, "secret", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.allowedUsernames = software.amazon.jsii.Kernel.get(this, "allowedUsernames", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.label = software.amazon.jsii.Kernel.get(this, "label", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.runsOn = software.amazon.jsii.Kernel.get(this, "runsOn", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.secret = java.util.Objects.requireNonNull(builder.secret, "secret is required");
            this.allowedUsernames = builder.allowedUsernames;
            this.label = builder.label;
            this.runsOn = builder.runsOn;
        }

        @Override
        public final java.lang.String getSecret() {
            return this.secret;
        }

        @Override
        public final java.util.List<java.lang.String> getAllowedUsernames() {
            return this.allowedUsernames;
        }

        @Override
        public final java.lang.String getLabel() {
            return this.label;
        }

        @Override
        public final java.util.List<java.lang.String> getRunsOn() {
            return this.runsOn;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("secret", om.valueToTree(this.getSecret()));
            if (this.getAllowedUsernames() != null) {
                data.set("allowedUsernames", om.valueToTree(this.getAllowedUsernames()));
            }
            if (this.getLabel() != null) {
                data.set("label", om.valueToTree(this.getLabel()));
            }
            if (this.getRunsOn() != null) {
                data.set("runsOn", om.valueToTree(this.getRunsOn()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.github.AutoApproveOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            AutoApproveOptions.Jsii$Proxy that = (AutoApproveOptions.Jsii$Proxy) o;

            if (!secret.equals(that.secret)) return false;
            if (this.allowedUsernames != null ? !this.allowedUsernames.equals(that.allowedUsernames) : that.allowedUsernames != null) return false;
            if (this.label != null ? !this.label.equals(that.label) : that.label != null) return false;
            return this.runsOn != null ? this.runsOn.equals(that.runsOn) : that.runsOn == null;
        }

        @Override
        public final int hashCode() {
            int result = this.secret.hashCode();
            result = 31 * result + (this.allowedUsernames != null ? this.allowedUsernames.hashCode() : 0);
            result = 31 * result + (this.label != null ? this.label.hashCode() : 0);
            result = 31 * result + (this.runsOn != null ? this.runsOn.hashCode() : 0);
            return result;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/github/AutoApproveOptions.java <==
package io.github.cdklabs.projen.github;

/**
 * (experimental) Options for 'AutoApprove'.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.413Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.github.AutoApproveOptions")
@software.amazon.jsii.Jsii.Proxy(AutoApproveOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface AutoApproveOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Only pull requests authored by these Github usernames will be auto-approved.
     * <p>
     * Default: ['github-bot']
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getAllowedUsernames() {
        return null;
    }

    /**
     * (experimental) Only pull requests with this label will be auto-approved.
     * <p>
     * Default: 'auto-approve'
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getLabel() {
        return null;
    }

    /**
     * (experimental) Github Runner selection labels.
     * <p>
     * Default: ["ubuntu-latest"]
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getRunsOn() {
        return null;
    }

    /**
     * (experimental) Github Runner Group selection options.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.GroupRunnerOptions getRunsOnGroup() {
        return null;
    }

    /**
     * (experimental) A GitHub secret name which contains a GitHub Access Token with write permissions for the <code>pull_request</code> scope.
     * <p>
     * This token is used to approve pull requests.
     * Github forbids an identity to approve its own pull request.
     * If your project produces automated pull requests using the Github default token -
     * {@link https://docs.github.com/en/actions/reference/authentication-in-a-workflow `GITHUB_TOKEN` }
     * * that you would like auto approved, such as when using the `depsUpgrade` property in
     *   `NodeProjectOptions`, then you must use a different token here.
     * <p>
     * Default: "GITHUB_TOKEN"
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getSecret() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link AutoApproveOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link AutoApproveOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<AutoApproveOptions> {
        java.util.List<java.lang.String> allowedUsernames;
        java.lang.String label;
        java.util.List<java.lang.String> runsOn;
        io.github.cdklabs.projen.GroupRunnerOptions runsOnGroup;
        java.lang.String secret;

        /**
         * Sets the value of {@link AutoApproveOptions#getAllowedUsernames}
         * @param allowedUsernames Only pull requests authored by these Github usernames will be auto-approved.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder allowedUsernames(java.util.List<java.lang.String> allowedUsernames) {
            this.allowedUsernames = allowedUsernames;
            return this;
        }

        /**
         * Sets the value of {@link AutoApproveOptions#getLabel}
         * @param label Only pull requests with this label will be auto-approved.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder label(java.lang.String label) {
            this.label = label;
            return this;
        }

        /**
         * Sets the value of {@link AutoApproveOptions#getRunsOn}
         * @param runsOn Github Runner selection labels.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder runsOn(java.util.List<java.lang.String> runsOn) {
            this.runsOn = runsOn;
            return this;
        }

        /**
         * Sets the value of {@link AutoApproveOptions#getRunsOnGroup}
         * @param runsOnGroup Github Runner Group selection options.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder runsOnGroup(io.github.cdklabs.projen.GroupRunnerOptions runsOnGroup) {
            this.runsOnGroup = runsOnGroup;
            return this;
        }

        /**
         * Sets the value of {@link AutoApproveOptions#getSecret}
         * @param secret A GitHub secret name which contains a GitHub Access Token with write permissions for the <code>pull_request</code> scope.
         *               This token is used to approve pull requests.
         *               
         *               Github forbids an identity to approve its own pull request.
         *               If your project produces automated pull requests using the Github default token -
         *               {@link https://docs.github.com/en/actions/reference/authentication-in-a-workflow `GITHUB_TOKEN` }
         *               
         *               * that you would like auto approved, such as when using the `depsUpgrade` property in
         *                 `NodeProjectOptions`, then you must use a different token here.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder secret(java.lang.String secret) {
            this.secret = secret;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link AutoApproveOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public AutoApproveOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link AutoApproveOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements AutoApproveOptions {
        private final java.util.List<java.lang.String> allowedUsernames;
        private final java.lang.String label;
        private final java.util.List<java.lang.String> runsOn;
        private final io.github.cdklabs.projen.GroupRunnerOptions runsOnGroup;
        private final java.lang.String secret;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.allowedUsernames = software.amazon.jsii.Kernel.get(this, "allowedUsernames", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.label = software.amazon.jsii.Kernel.get(this, "label", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.runsOn = software.amazon.jsii.Kernel.get(this, "runsOn", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
            this.runsOnGroup = software.amazon.jsii.Kernel.get(this, "runsOnGroup", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.GroupRunnerOptions.class));
            this.secret = software.amazon.jsii.Kernel.get(this, "secret", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.allowedUsernames = builder.allowedUsernames;
            this.label = builder.label;
            this.runsOn = builder.runsOn;
            this.runsOnGroup = builder.runsOnGroup;
            this.secret = builder.secret;
        }

        @Override
        public final java.util.List<java.lang.String> getAllowedUsernames() {
            return this.allowedUsernames;
        }

        @Override
        public final java.lang.String getLabel() {
            return this.label;
        }

        @Override
        public final java.util.List<java.lang.String> getRunsOn() {
            return this.runsOn;
        }

        @Override
        public final io.github.cdklabs.projen.GroupRunnerOptions getRunsOnGroup() {
            return this.runsOnGroup;
        }

        @Override
        public final java.lang.String getSecret() {
            return this.secret;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getAllowedUsernames() != null) {
                data.set("allowedUsernames", om.valueToTree(this.getAllowedUsernames()));
            }
            if (this.getLabel() != null) {
                data.set("label", om.valueToTree(this.getLabel()));
            }
            if (this.getRunsOn() != null) {
                data.set("runsOn", om.valueToTree(this.getRunsOn()));
            }
            if (this.getRunsOnGroup() != null) {
                data.set("runsOnGroup", om.valueToTree(this.getRunsOnGroup()));
            }
            if (this.getSecret() != null) {
                data.set("secret", om.valueToTree(this.getSecret()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.github.AutoApproveOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            AutoApproveOptions.Jsii$Proxy that = (AutoApproveOptions.Jsii$Proxy) o;

            if (this.allowedUsernames != null ? !this.allowedUsernames.equals(that.allowedUsernames) : that.allowedUsernames != null) return false;
            if (this.label != null ? !this.label.equals(that.label) : that.label != null) return false;
            if (this.runsOn != null ? !this.runsOn.equals(that.runsOn) : that.runsOn != null) return false;
            if (this.runsOnGroup != null ? !this.runsOnGroup.equals(that.runsOnGroup) : that.runsOnGroup != null) return false;
            return this.secret != null ? this.secret.equals(that.secret) : that.secret == null;
        }

        @Override
        public final int hashCode() {
            int result = this.allowedUsernames != null ? this.allowedUsernames.hashCode() : 0;
            result = 31 * result + (this.label != null ? this.label.hashCode() : 0);
            result = 31 * result + (this.runsOn != null ? this.runsOn.hashCode() : 0);
            result = 31 * result + (this.runsOnGroup != null ? this.runsOnGroup.hashCode() : 0);
            result = 31 * result + (this.secret != null ? this.secret.hashCode() : 0);
            return result;
        }
    }
}
